h5torch package
===============

.. autoclass:: h5torch.file.File     
   :members: 
   :undoc-members:

.. autoclass:: h5torch.dataset.Dataset     
   :members:
   :undoc-members:

.. autoclass:: h5torch.dataset.SliceDataset     
   :members: 
   :undoc-members:

